@@ -7,33 +7,10 @@ from kisters.network_store.model_library.util import (
     all_nodes,
     element_from_dict,
     element_to_dict,
+    elements_mapping,
 )
-from kisters.network_store.model_library.water.util import all_links as all_links_water
-from kisters.network_store.model_library.water.util import all_nodes as all_nodes_water
 
 elements = [
-    {
-        "uid": "channel",
-        "source_uid": "junction",
-        "target_uid": "storage",
-        "stations": [
-            {
-                "roughness": 10.0,
-                "cross_section": [
-                    {"z": 0, "lr": -5},
-                    {"z": 0, "lr": 5},
-                    {"z": 10, "lr": -5},
-                    {"z": 10, "lr": 5},
-                ],
-            }
-        ],
-        "length": 100.0,
-        "model": "saint-venant",
-        "roughness_model": "chezy",
-        "display_name": "channel",
-        "element_class": "Channel",
-        "domain": "water",
-    },
     {
         "uid": "delay",
         "created": "2020-03-04T11:02:16.790000+00:00",
@@ -178,10 +155,10 @@ def test_parse(element: Dict[str, Any]) -> None:
 
 
 def test_util_entry_point() -> None:
-    assert all_links_water
-    assert all_nodes_water
-    assert set(all_links_water.values()).issubset(set(all_links))
-    assert set(all_nodes_water.values()).issubset(set(all_nodes))
+    assert elements_mapping["water"]["links"]
+    assert elements_mapping["water"]["nodes"]
+    assert set(elements_mapping["water"]["links"].values()).issubset(set(all_links))
+    assert set(elements_mapping["water"]["nodes"].values()).issubset(set(all_nodes))
 
 
 @pytest.mark.parametrize("element", elements)
